@@ -22,6 +22,7 @@ from .plotting.animate import (
     animate_poloidal,
     animate_pcolormesh,
     animate_line,
+    _add_controls,
     _normalise_time_coord,
     _parse_coord_option,
 )
@@ -261,7 +262,7 @@ class BoutDatasetAccessor:
 
         return ds
 
-    def integrate_midpoints(self, variable, *, dims=None):
+    def integrate_midpoints(self, variable, *, dims=None, cumulative_t=False):
         """
         Integrate using the midpoint rule for spatial dimensions, and trapezium rule for
         time.
@@ -302,6 +303,10 @@ class BoutDatasetAccessor:
             Dimensions to integrate over. Can be any combination of of the dimensions of
             the Dataset. Defaults to integration over all spatial dimensions. If `...`
             is passed, integrate over all dimensions including time.
+        cumulative_t : bool, default False
+            If integrating in time, return the cumulative integral (integral from the
+            beginning up to each point in the time dimension) instead of the definite
+            integral.
         """
         ds = self.data
 
@@ -339,7 +344,10 @@ class BoutDatasetAccessor:
 
         dx = ds[f"dx{suffix}"]
         dy = ds[f"dy{suffix}"]
-        dz = ds.metadata["dz"]
+        if ds.metadata["BOUT_VERSION"] >= 5.0:
+            dz = ds[f"dz{suffix}"]
+        else:
+            dz = ds["dz"]
 
         # Work out the spatial volume element
         if xcoord in dims and ycoord in dims and zcoord in dims:
@@ -447,7 +455,10 @@ class BoutDatasetAccessor:
             integral = integral * ds.sizes[zcoord]
 
         if tcoord in dims:
-            integral = integral.integrate(dim=tcoord)
+            if cumulative_t:
+                integral = integral.cumulative_integrate(coord=tcoord)
+            else:
+                integral = integral.integrate(coord=tcoord)
 
         return integral
 
@@ -838,7 +849,7 @@ class BoutDatasetAccessor:
         titles=None,
         aspect=None,
         extend=None,
-        controls=True,
+        controls="both",
         tight_layout=True,
         **kwargs,
     ):
@@ -901,14 +912,22 @@ class BoutDatasetAccessor:
             plots and "auto" for others.
         extend : str or None, optional
             Passed to fig.colorbar()
-        controls : bool, optional
-            If set to False, do not show the time-slider or pause button
+        controls : string or None, default "both"
+            By default, add both the timeline and play/pause toggle to the animation. If
+            "timeline" is passed add only the timeline, if "toggle" is passed add only
+            the play/pause toggle. If None or an empty string is passed, add neither.
         tight_layout : bool or dict, optional
             If set to False, don't call tight_layout() on the figure.
             If a dict is passed, the dict entries are passed as arguments to
             tight_layout()
         **kwargs : dict, optional
-            Additional keyword arguments are passed on to each animation function
+            Additional keyword arguments are passed on to each animation function, per
+            variable if a sequence is given.
+
+        Returns
+        -------
+        animation
+            An animatplot.Animation object.
         """
 
         if animate_over is None:
@@ -958,6 +977,8 @@ class BoutDatasetAccessor:
         aspect = _expand_list_arg(aspect, "aspect")
         extend = _expand_list_arg(extend, "extend")
         axis_coords = _expand_list_arg(axis_coords, "axis_coords")
+        for k in kwargs:
+            kwargs[k] = _expand_list_arg(kwargs[k], k)
 
         blocks = []
 
@@ -968,17 +989,19 @@ class BoutDatasetAccessor:
                 or isinstance(variable, set)
             )
 
-        for subplot_args in zip(
-            variables,
-            axes,
-            poloidal_plot,
-            axis_coords,
-            vmin,
-            vmax,
-            logscale,
-            titles,
-            aspect,
-            extend,
+        for i, subplot_args in enumerate(
+            zip(
+                variables,
+                axes,
+                poloidal_plot,
+                axis_coords,
+                vmin,
+                vmax,
+                logscale,
+                titles,
+                aspect,
+                extend,
+            )
         ):
 
             (
@@ -994,6 +1017,8 @@ class BoutDatasetAccessor:
                 this_extend,
             ) = subplot_args
 
+            this_kwargs = {k: v[i] for k, v in kwargs.items()}
+
             divider = make_axes_locatable(ax)
             cax = divider.append_axes("right", size="5%", pad=0.1)
 
@@ -1033,7 +1058,7 @@ class BoutDatasetAccessor:
                             animate=False,
                             axis_coords=this_axis_coords,
                             aspect=this_aspect,
-                            **kwargs,
+                            **this_kwargs,
                         )
                     )
                 else:
@@ -1047,7 +1072,7 @@ class BoutDatasetAccessor:
                                 axis_coords=this_axis_coords,
                                 aspect=this_aspect,
                                 label=w.name,
-                                **kwargs,
+                                **this_kwargs,
                             )
                         )
                     legend = ax.legend()
@@ -1068,7 +1093,7 @@ class BoutDatasetAccessor:
                         logscale=this_logscale,
                         aspect=this_aspect,
                         extend=this_extend,
-                        **kwargs,
+                        **this_kwargs,
                     )
                     for block in var_blocks:
                         blocks.append(block)
@@ -1086,7 +1111,7 @@ class BoutDatasetAccessor:
                             logscale=this_logscale,
                             aspect=this_aspect,
                             extend=this_extend,
-                            **kwargs,
+                            **this_kwargs,
                         )
                     )
             else:
@@ -1136,8 +1161,7 @@ class BoutDatasetAccessor:
                 tight_layout = {}
             fig.tight_layout(**tight_layout)
 
-        if controls:
-            anim.controls(timeline_slider_args={"text": time_label})
+        _add_controls(anim, controls, time_label)
 
         if save_as is not None:
             anim.save(save_as + ".gif", writer=PillowWriter(fps=fps))
