@@ -25,6 +25,23 @@ if (
     matplotlib.rcParams["pcolor.shading"] = "auto"
 
 
+def _add_controls(anim, controls, t_label):
+    if controls == "both":
+        # Add both time slider and play/pause toggle
+        anim.controls(timeline_slider_args={"text": t_label})
+    elif controls == "timeline":
+        # Add time slider
+        anim.timeline_slider(text=t_label)
+    elif controls == "toggle":
+        # Add play/pause toggle
+        anim.toggle()
+    elif controls is None or controls == "":
+        # Add no controls
+        pass
+    else:
+        raise ValueError(f"Unrecognised value for controls={controls}")
+
+
 def _parse_coord_option(coord, axis_coords, da):
     if isinstance(axis_coords, dict):
         option_value = axis_coords.get(coord, None)
@@ -90,7 +107,7 @@ def animate_poloidal(
     animate=True,
     save_as=None,
     fps=10,
-    controls=True,
+    controls="both",
     aspect=None,
     extend=None,
     **kwargs,
@@ -146,8 +163,10 @@ def animate_poloidal(
         '<variable name>_over_<animate_over>.gif'
     fps : float, optional
         Frame rate for the animation
-    controls : bool, optional
-        If False, do not add the timeline and pause button to the animation
+    controls : string or None, default "both"
+        By default, add both the timeline and play/pause toggle to the animation. If
+        "timeline" is passed add only the timeline, if "toggle" is passed add only the
+        play/pause toggle. If None or an empty string is passed, add neither.
     aspect : str or None, optional
         Argument to set_aspect(), defaults to "equal"
     extend : str or None, optional
@@ -158,8 +177,9 @@ def animate_poloidal(
 
     Returns
     -------
-    blocks
-        List of animatplot.blocks.Pcolormesh instances
+    animation or blocks
+        If animate==True, returns an animatplot.Animation object, otherwise
+        returns a list of animatplot.blocks.Pcolormesh instances.
     """
 
     if animate_over is None:
@@ -267,14 +287,15 @@ def animate_poloidal(
         timeline = amp.Timeline(t_values, fps=fps, units=t_suffix)
         anim = amp.Animation(blocks, timeline)
 
-        if controls:
-            anim.controls(timeline_slider_args={"text": t_label})
+        _add_controls(anim, controls, t_label)
 
         if save_as is not None:
             if save_as is True:
                 save_as = "{}_over_{}".format(da.name, animate_over)
             anim.save(save_as + ".gif", writer=PillowWriter(fps=fps))
 
+        return anim
+
     return blocks
 
 
@@ -295,7 +316,7 @@ def animate_pcolormesh(
     cax=None,
     aspect=None,
     extend=None,
-    controls=True,
+    controls="both",
     **kwargs,
 ):
     """
@@ -357,11 +378,19 @@ def animate_pcolormesh(
         Argument to set_aspect(), defaults to "auto"
     extend : str or None, optional
         Passed to fig.colorbar()
-    controls : bool, optional
-        If False, do not add the timeline and pause button to the animation
+    controls : string or None, default "both"
+        By default, add both the timeline and play/pause toggle to the animation. If
+        "timeline" is passed add only the timeline, if "toggle" is passed add only the
+        play/pause toggle. If None or an empty string is passed, add neither.
     kwargs : dict, optional
         Additional keyword arguments are passed on to the animation function
         animatplot.blocks.Pcolormesh
+
+    Returns
+    -------
+    animation or block
+        If animate==True, returns an animatplot.Animation object, otherwise
+        returns an animatplot.blocks.Pcolormesh instance.
     """
 
     if animate_over is None:
@@ -471,14 +500,15 @@ def animate_pcolormesh(
     ax.set_ylabel(y_label)
 
     if animate:
-        if controls:
-            anim.controls(timeline_slider_args={"text": t_label})
+        _add_controls(anim, controls, t_label)
 
         if save_as is not None:
             if save_as is True:
                 save_as = "{}_over_{}".format(variable, animate_over)
             anim.save(save_as + ".gif", writer=PillowWriter(fps=fps))
 
+        return anim
+
     return pcolormesh_block
 
 
@@ -494,7 +524,7 @@ def animate_line(
     sep_pos=None,
     ax=None,
     aspect=None,
-    controls=True,
+    controls="both",
     **kwargs,
 ):
     """
@@ -537,11 +567,19 @@ def animate_line(
         figure and axes, and plot to that
     aspect : str or None, optional
         Argument to set_aspect(), defaults to "auto"
-    controls : bool, optional
-        If False, do not add the timeline and pause button to the animation
+    controls : string or None, default "both"
+        By default, add both the timeline and play/pause toggle to the animation. If
+        "timeline" is passed add only the timeline, if "toggle" is passed add only the
+        play/pause toggle. If None or an empty string is passed, add neither.
     kwargs : dict, optional
         Additional keyword arguments are passed on to the plotting function
         animatplot.blocks.Line
+
+    Returns
+    -------
+    animation or block
+        If animate==True, returns an animatplot.Animation object, otherwise
+        returns an animatplot.blocks.Line instance.
     """
 
     if animate_over is None:
@@ -606,12 +644,13 @@ def animate_line(
         ax.plot_vline(sep_pos, "--")
 
     if animate:
-        if controls:
-            anim.controls(timeline_slider_args={"text": t_label})
+        _add_controls(anim, controls, t_label)
 
         if save_as is not None:
             if save_as is True:
                 save_as = "{}_over_{}".format(variable, animate_over)
             anim.save(save_as + ".gif", writer=PillowWriter(fps=fps))
 
+        return anim
+
     return line_block
