@@ -1218,7 +1218,7 @@ class TestBoutDatasetMethods:
         ds["t"].data[...] = t.squeeze()
         ds["dx"].data[...] = 0.1
         ds["dy"].data[...] = 0.2
-        ds.metadata["dz"] = 0.3
+        ds["dz"] = 0.3
         tfunc = 1.5 * t
         xfunc = x ** 2
         yfunc = 10.0 * y - y ** 2
@@ -1354,6 +1354,7 @@ class TestBoutDatasetMethods:
             r = r - Lr / (2.0 * nx)
         q = options.evaluate_scalar("mesh:q")
         T_total = (ds.sizes["t"] - 1) * (ds["t"][1] - ds["t"][0]).values
+        T_cumulative = np.arange(ds.sizes["t"]) * (ds["t"][1] - ds["t"][0]).values
 
         # Volume of torus with circular cross-section of major radius R and minor radius
         # a is 2*pi*R*pi*a^2
@@ -1386,6 +1387,15 @@ class TestBoutDatasetMethods:
             rtol=1.0e-5,
             atol=0.0,
         )
+        # Cumulative integral in time
+        npt.assert_allclose(
+            ds.bout.integrate_midpoints(
+                "n", dims=["t", "x", "theta", "zeta"], cumulative_t=True
+            ),
+            T_cumulative * 2.0 * np.pi * R * np.pi * (router ** 2 - rinner ** 2),
+            rtol=1.0e-5,
+            atol=0.0,
+        )
 
         # Area of torus with circular cross-section of major radius R and minor radius a
         # is 2*pi*R*2*pi*a
@@ -1404,6 +1414,16 @@ class TestBoutDatasetMethods:
             rtol=1.0e-5,
             atol=0.0,
         )
+        # Cumulative integral in time
+        npt.assert_allclose(
+            ds.bout.integrate_midpoints(
+                "n", dims=["t", "theta", "zeta"], cumulative_t=True
+            ),
+            T_cumulative[:, np.newaxis]
+            * (2.0 * np.pi * R * 2.0 * np.pi * r)[np.newaxis, :],
+            rtol=1.0e-5,
+            atol=0.0,
+        )
 
         # Area of cross section in poloidal plane is difference of circle with radius
         # router and circle with radius rinner, pi*(router**2 - rinner**2)
@@ -1420,6 +1440,18 @@ class TestBoutDatasetMethods:
             rtol=1.0e-5,
             atol=0.0,
         )
+        # Cumulative integral in time
+        npt.assert_allclose(
+            ds.bout.integrate_midpoints(
+                "n", dims=["t", "x", "theta"], cumulative_t=True
+            ),
+            T_cumulative[:, np.newaxis]
+            * np.pi
+            * (router ** 2 - rinner ** 2)
+            * np.ones(ds.sizes["zeta"])[np.newaxis, :],
+            rtol=1.0e-5,
+            atol=0.0,
+        )
 
         # x-z planes are 'conical frustrums', with area pi*(Rinner + Router)*Lr
         # https://en.wikipedia.org/wiki/Frustum
@@ -1442,6 +1474,17 @@ class TestBoutDatasetMethods:
             rtol=1.0e-5,
             atol=0.0,
         )
+        # Cumulative integral in time
+        npt.assert_allclose(
+            ds.bout.integrate_midpoints(
+                "n", dims=["t", "x", "zeta"], cumulative_t=True
+            ),
+            T_cumulative[:, np.newaxis]
+            * (np.pi * (Rinner + Router) * Lr)
+            * np.ones(ds.sizes["theta"])[np.newaxis, :],
+            rtol=1.0e-5,
+            atol=0.0,
+        )
 
         # Radial lines have length Lr
         npt.assert_allclose(
@@ -1457,6 +1500,15 @@ class TestBoutDatasetMethods:
             rtol=1.0e-5,
             atol=0.0,
         )
+        # Cumulative integral in time
+        npt.assert_allclose(
+            ds.bout.integrate_midpoints("n", dims=["t", "x"], cumulative_t=True),
+            T_cumulative[:, np.newaxis, np.newaxis]
+            * Lr
+            * np.ones([ds.sizes["theta"], ds.sizes["zeta"]])[np.newaxis, :, :],
+            rtol=1.0e-5,
+            atol=0.0,
+        )
 
         # Poloidal lines have length 2*pi*r
         npt.assert_allclose(
@@ -1476,6 +1528,15 @@ class TestBoutDatasetMethods:
             rtol=1.0e-5,
             atol=0.0,
         )
+        # Cumulative integral in time
+        npt.assert_allclose(
+            ds.bout.integrate_midpoints("n", dims=["t", "theta"], cumulative_t=True),
+            T_cumulative[:, np.newaxis, np.newaxis]
+            * (2.0 * np.pi * r)[np.newaxis, :, np.newaxis]
+            * np.ones(ds.sizes["zeta"])[np.newaxis, np.newaxis, :],
+            rtol=1.0e-5,
+            atol=0.0,
+        )
 
         # Field line length
         # -----------------
@@ -1555,6 +1616,17 @@ class TestBoutDatasetMethods:
             rtol=1.0e-5,
             atol=0.0,
         )
+        # Cumulative integral in time
+        npt.assert_allclose(
+            ds.bout.integrate_midpoints(
+                "n_aligned", dims=["t", "theta"], cumulative_t=True
+            ),
+            T_cumulative[:, np.newaxis, np.newaxis]
+            * integral[np.newaxis, :, np.newaxis]
+            * np.ones(ds.sizes["zeta"])[np.newaxis, np.newaxis, :],
+            rtol=1.0e-5,
+            atol=0.0,
+        )
 
         # Toroidal lines have length 2*pi*Rxy
         if location == "CELL_CENTRE":
@@ -1575,6 +1647,14 @@ class TestBoutDatasetMethods:
             rtol=1.0e-5,
             atol=0.0,
         )
+        # Cumulative integral in time
+        npt.assert_allclose(
+            ds.bout.integrate_midpoints("n", dims=["t", "zeta"], cumulative_t=True),
+            T_cumulative[:, np.newaxis, np.newaxis]
+            * (2.0 * np.pi * R_2d).values[np.newaxis, :, :],
+            rtol=1.0e-5,
+            atol=0.0,
+        )
 
     def test_interpolate_from_unstructured(self, bout_xyt_example_files):
         dataset_list, grid_ds = bout_xyt_example_files(
@@ -2006,6 +2086,9 @@ class TestSaveRestart:
                 t_array = check_ds["t"]
                 check_ds = check_ds.drop_vars(["t", "x", "y", "z"])
 
+                # No coordinates saved in restart files, so unset them in check_ds
+                check_ds = check_ds.reset_coords()
+
                 for v in restart_ds:
                     if v in check_ds:
                         xrt.assert_equal(restart_ds[v], check_ds[v])
@@ -2065,6 +2148,9 @@ class TestSaveRestart:
                 t_array = check_ds["t"]
                 check_ds = check_ds.drop_vars(["t", "x", "y", "z"])
 
+                # No coordinates saved in restart files, so unset them in check_ds
+                check_ds = check_ds.reset_coords()
+
                 for v in restart_ds:
                     if v in check_ds:
                         xrt.assert_equal(restart_ds[v], check_ds[v])
@@ -2130,6 +2216,9 @@ class TestSaveRestart:
                 t_array = check_ds["t"]
                 check_ds = check_ds.drop_vars(["t", "x", "y", "z"])
 
+                # No coordinates saved in restart files, so unset them in check_ds
+                check_ds = check_ds.reset_coords()
+
                 for v in restart_ds:
                     if v in check_ds:
                         xrt.assert_equal(restart_ds[v], check_ds[v])
