@@ -260,6 +260,8 @@ def _bout_xyt_example_files(
     squashed=False,
     topology="core",
     write_to_disk=False,
+    bout_v5=False,
+    metric_3D=False,
 ):
     """
     Mocks up a set of BOUT-like Datasets
@@ -292,6 +294,8 @@ def _bout_xyt_example_files(
             topology=topology,
             syn_data_type=syn_data_type,
             squashed=True,
+            bout_v5=bout_v5,
+            metric_3D=metric_3D,
         )
         ds_list[0]["nxpe"] = nxpe
         ds_list[0]["nype"] = nype
@@ -305,6 +309,8 @@ def _bout_xyt_example_files(
             guards=guards,
             topology=topology,
             syn_data_type=syn_data_type,
+            bout_v5=bout_v5,
+            metric_3D=metric_3D,
         )
 
     if grid is not None:
@@ -358,6 +364,8 @@ def create_bout_ds_list(
     topology="core",
     syn_data_type="random",
     squashed=False,
+    bout_v5=False,
+    metric_3D=False,
 ):
     """
     Mocks up a set of BOUT-like datasets.
@@ -394,6 +402,8 @@ def create_bout_ds_list(
                 guards=guards,
                 topology=topology,
                 squashed=squashed,
+                bout_v5=bout_v5,
+                metric_3D=metric_3D,
             )
             ds_list.append(ds)
 
@@ -408,11 +418,19 @@ def create_bout_ds(
     nype=1,
     xproc=0,
     yproc=0,
-    guards={},
+    guards=None,
     topology="core",
     squashed=False,
+    bout_v5=False,
+    metric_3D=False,
 ):
 
+    if metric_3D and not bout_v5:
+        raise ValueError("3D metric requires BOUT++ v5")
+
+    if guards is None:
+        guards = {}
+
     # Set the shape of the data in this dataset
     t_length, x_length, y_length, z_length = lengths
     mxg = guards.get("x", 0)
@@ -469,9 +487,14 @@ def create_bout_ds(
         v.attrs["cell_location"] = "CELL_CENTRE"
     ds = Dataset({"n": n, "T": T})
 
-    # BOUT_VERSION needed so that we know that number of points in z is MZ, not MZ-1 (as
-    # it was in BOUT++ before v4.0
-    ds["BOUT_VERSION"] = 4.3
+    # BOUT_VERSION needed to deal with backwards incompatible changes:
+    #
+    # - v3 and earlier: number of points in z is MZ-1
+    # - v4 and later: number of points in z is MZ
+    # - v5 and later: metric components can be either 2D or 3D
+    # - v5 and later: dz changed to be a Field2D/3D
+    ds["BOUT_VERSION"] = 5.0 if bout_v5 else 4.3
+    ds["use_metric_3d"] = int(metric_3D)
 
     # Include grid data
     ds["NXPE"] = nxpe
@@ -601,8 +624,12 @@ def create_bout_ds(
     else:
         raise ValueError(f"Unrecognised topology={topology}")
 
-    one = DataArray(np.ones((x_length, y_length)), dims=["x", "y"])
-    zero = DataArray(np.zeros((x_length, y_length)), dims=["x", "y"])
+    if metric_3D:
+        one = DataArray(np.ones((x_length, y_length, z_length)), dims=["x", "y", "z"])
+        zero = DataArray(np.zeros((x_length, y_length, z_length)), dims=["x", "y", "z"])
+    else:
+        one = DataArray(np.ones((x_length, y_length)), dims=["x", "y"])
+        zero = DataArray(np.zeros((x_length, y_length)), dims=["x", "y"])
 
     ds["zperiod"] = 1
     ds["ZMIN"] = 0.0
@@ -628,8 +655,10 @@ def create_bout_ds(
 
     ds["dx"] = 0.5 * one
     ds["dy"] = 2.0 * one
-    ds = ds.set_coords(["dx", "dy"])
-    ds["dz"] = 2.0 * np.pi / nz
+    if bout_v5:
+        ds["dz"] = 2.0 * one * np.pi / nz
+    else:
+        ds["dz"] = 2.0 * np.pi / nz
 
     ds["iteration"] = t_length
     ds["t_array"] = DataArray(np.arange(t_length, dtype=float) * 10.0, dims="t")
@@ -709,7 +738,7 @@ METADATA_VARS = [
     "zperiod",
     "ZMIN",
     "ZMAX",
-    "dz",
+    "use_metric_3d",
 ]
 
 
@@ -737,7 +766,9 @@ class TestOpen:
         with pytest.warns(UserWarning):
             actual = open_boutdataset(datapath=path, keep_xboundaries=False)
         expected = create_bout_ds()
-        expected = expected.set_coords("t_array").rename(t_array="t")
+        expected = expected.set_coords(["t_array", "dx", "dy", "dz"]).rename(
+            t_array="t"
+        )
         xrt.assert_equal(
             actual.drop_vars(["x", "y", "z"]).load(),
             expected.drop_vars(
@@ -761,7 +792,9 @@ class TestOpen:
         with pytest.warns(UserWarning):
             actual = open_boutdataset(datapath=path, keep_xboundaries=False)
         expected = create_bout_ds(lengths=(6, 8, 12, 7))
-        expected = expected.set_coords("t_array").rename(t_array="t")
+        expected = expected.set_coords(["t_array", "dx", "dy", "dz"]).rename(
+            t_array="t"
+        )
         xrt.assert_equal(
             actual.drop_vars(["x", "y", "z"]).load(),
             expected.drop_vars(
@@ -865,7 +898,9 @@ class TestOpen:
             dim="x",
             data_vars="minimal",
         )
-        expected = expected.set_coords("t_array").rename(t_array="t")
+        expected = expected.set_coords(["t_array", "dx", "dy", "dz"]).rename(
+            t_array="t"
+        )
         xrt.assert_equal(
             actual.drop_vars(["x", "y", "z"]).load(),
             expected.drop_vars(
@@ -897,7 +932,9 @@ class TestOpen:
         expected = concat(
             [bout_ds(0), bout_ds(1), bout_ds(2)], dim="y", data_vars="minimal"
         )
-        expected = expected.set_coords("t_array").rename(t_array="t")
+        expected = expected.set_coords(["t_array", "dx", "dy", "dz"]).rename(
+            t_array="t"
+        )
         xrt.assert_equal(
             actual.drop_vars(["x", "y", "z"]).load(),
             expected.drop_vars(
@@ -917,19 +954,32 @@ class TestOpen:
     def test_combine_along_t(self):
         ...
 
-    def test_combine_along_xy(self, tmpdir_factory, bout_xyt_example_files):
+    @pytest.mark.parametrize(
+        "bout_v5,metric_3D", [(False, False), (True, False), (True, True)]
+    )
+    @pytest.mark.parametrize("lengths", [(6, 2, 4, 7), (6, 2, 4, 1)])
+    def test_combine_along_xy(
+        self, tmpdir_factory, bout_xyt_example_files, bout_v5, metric_3D, lengths
+    ):
         path = bout_xyt_example_files(
             tmpdir_factory,
             nxpe=4,
             nype=3,
             nt=1,
+            lengths=lengths,
             syn_data_type="stepped",
             write_to_disk=True,
+            bout_v5=bout_v5,
+            metric_3D=metric_3D,
         )
         with pytest.warns(UserWarning):
             actual = open_boutdataset(datapath=path, keep_xboundaries=False)
 
-        bout_ds = create_bout_ds
+        def bout_ds(syn_data_type):
+            return create_bout_ds(
+                syn_data_type, bout_v5=bout_v5, metric_3D=metric_3D, lengths=lengths
+            )
+
         line1 = concat(
             [bout_ds(0), bout_ds(1), bout_ds(2), bout_ds(3)],
             dim="x",
@@ -946,17 +996,25 @@ class TestOpen:
             data_vars="minimal",
         )
         expected = concat([line1, line2, line3], dim="y", data_vars="minimal")
-        expected = expected.set_coords("t_array").rename(t_array="t")
+        expected = expected.set_coords(["t_array", "dx", "dy", "dz"]).rename(
+            t_array="t"
+        )
+        vars_to_drop = METADATA_VARS + _BOUT_PER_PROC_VARIABLES
         xrt.assert_equal(
             actual.drop_vars(["x", "y", "z"]).load(),
-            expected.drop_vars(
-                METADATA_VARS + _BOUT_PER_PROC_VARIABLES, errors="ignore"
-            ),
+            expected.drop_vars(vars_to_drop, errors="ignore"),
         )
 
         # check creation without writing to disk gives identical result
         fake_ds_list = bout_xyt_example_files(
-            None, nxpe=4, nype=3, nt=1, syn_data_type="stepped"
+            None,
+            nxpe=4,
+            nype=3,
+            nt=1,
+            lengths=lengths,
+            syn_data_type="stepped",
+            bout_v5=bout_v5,
+            metric_3D=metric_3D,
         )
         with pytest.warns(UserWarning):
             fake = open_boutdataset(datapath=fake_ds_list, keep_xboundaries=False)
